from .kernel import SSHKernel

if __name__ == "__main__":
    SSHKernel.run_as_main()
